@@ -1,17 +1,17 @@
 # Copyright 2005 Lars Wirzenius (liw@iki.fi)
-# 
+#
 # This program is free software; you can redistribute it and/or modify it
 # under the terms of the GNU General Public License as published by the
 # Free Software Foundation; either version 2 of the License, or (at your
 # option) any later version.
-# 
+#
 # This program is distributed in the hope that it will be useful, but
 # WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General
 # Public License for more details.
-# 
+#
 # You should have received a copy of the GNU General Public License along with
-# this program; if not, write to the Free Software Foundation, Inc., 
+# this program; if not, write to the Free Software Foundation, Inc.,
 # 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
 
 
@@ -30,12 +30,14 @@ def open_packages_url(url):
     assert url.endswith(".bz2")
     socket = urllib.urlopen(url)
     decompressor = bz2.BZ2Decompressor()
-    file = cStringIO.StringIO()
+    bzfile = cStringIO.StringIO()
     while True:
         data = socket.read(1024)
         if not data:
             break
-        file.write(decompressor.decompress(data))
+        bzfile.write(decompressor.decompress(data))
     socket.close()
-    file.seek(0)
-    return file
+    bzfile.seek(0)
+    return bzfile
+
+# vi:set et ts=4 sw=4 :
